#ifndef __GWEATHER_PREF_H_
#define __GWEATHER_PREF_H_

/* $Id: gweather-pref.h,v 1.10 2005/12/12 00:22:17 philipl Exp $ */

/*
 *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
 *
 *  This code released under the GNU GPL.
 *  Read the file COPYING for more information.
 *
 *  Preferences dialog
 *
 */

#include "gweather.h"

G_BEGIN_DECLS

extern void gweather_pref_run (GWeatherApplet *gw_applet);

void add_atk_relation (GtkWidget *widget1, GtkWidget *widget2, AtkRelationType type);
void set_access_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc);

enum
{
    GWEATHER_PREF_COL_LOC = 0,
    GWEATHER_PREF_COL_POINTER,
    GWEATHER_PREF_NUM_COLUMNS
}; 



G_END_DECLS

#endif /* __GWEATHER_PREF_H_ */

